@@ -51,6 +51,8 @@ mktime_from_string (char *month,
 				   "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };
 	struct tm     tm = {0, };
 
+	tm.tm_isdst = -1;
+
 	if (month != NULL) {
 		int i;
 		for (i = 0; i < 12; i++)
@@ -120,7 +122,7 @@ list__process_line (char     *line,
 		fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 		fdata->path = remove_level_from_path (fdata->full_path);
 
-		comm->file_list = g_list_prepend (comm->file_list, fdata);
+		fr_command_add_file (comm, fdata);
 	}
 }
 
