@@ -178,16 +178,21 @@ static GtkToggleActionEntry action_toggle_entries[] = {
 	  N_("Reverse the list order"),
 	  G_CALLBACK (activate_action_sort_reverse_order), 
 	  FALSE },
+	{ "ViewFolders", NULL,
+	  N_("_Folders"), "F9",
+	  N_("View the folders pane"),
+	  G_CALLBACK (activate_action_view_folders), 
+	  FALSE },
 };
 static guint n_action_toggle_entries = G_N_ELEMENTS (action_toggle_entries);
 
 
 static GtkRadioActionEntry view_as_entries[] = {
 	{ "ViewAllFiles", NULL,
-	  N_("View All _Files"), NULL,
+	  N_("View All _Files"), "<control>1",
 	  " ", FR_WINDOW_LIST_MODE_FLAT },
 	{ "ViewAsFolder", NULL,
-	  N_("View as a F_older"), NULL,
+	  N_("View as a F_older"), "<control>2",
 	  " ", FR_WINDOW_LIST_MODE_AS_DIR },
 };
 static guint n_view_as_entries = G_N_ELEMENTS (view_as_entries);
@@ -247,14 +252,12 @@ static const gchar *ui_info =
 "      <menuitem action='Password'/>"
 "    </menu>"
 "    <menu action='ViewMenu'>"
-"      <menuitem action='ViewToolbar'/>"
-"      <menuitem action='ViewStatusbar'/>"
-"      <separator/>"
 "      <menuitem action='Stop'/>"
 "      <menuitem action='Reload'/>"
 "      <separator/>"
-"      <menuitem action='ViewAllFiles'/>"
-"      <menuitem action='ViewAsFolder'/>"
+"      <menuitem action='ViewToolbar'/>"
+"      <menuitem action='ViewStatusbar'/>"
+"      <menuitem action='ViewFolders'/>"
 "      <separator/>"
 "      <menu action='ArrangeFilesMenu'>"
 "        <menuitem action='SortByName'/>"
@@ -266,6 +269,9 @@ static const gchar *ui_info =
 "        <menuitem action='SortReverseOrder'/>"
 "      </menu>"
 "      <separator/>"
+"      <menuitem action='ViewAllFiles'/>"
+"      <menuitem action='ViewAsFolder'/>" 
+"      <separator/>"
 "      <menuitem action='LastOutput'/>"
 "    </menu>"
 "    <menu action='HelpMenu'>"
